//Source file: CallLegInfoReport.java
//Date: June 2004
//Multi Party Call Control Data Types for 3GPP TS 29.198-04-3 V5.7.0

package org.csapi.jr.se.cc;

/**
 * Defines the Sequence of Data Elements that specify the call leg information requested. 
 * 
 */
public final class CallLegInfoReport implements java.io.Serializable {

    private int callLegInfoType;
    private String callLegStartTime;
    private String callLegConnectedToResourceTime;
    private String callLegConnectedToAddressTime;
    private String callLegEndTime;
    private org.csapi.jr.se.Address connectedAddress;
    private org.csapi.jr.se.cc.ReleaseCause callLegReleaseCause;
    private org.csapi.jr.se.cc.CallAppInfo[] callAppInfo;

    /**
     * Creates a new CallLegInfoReport instance.
     */
    public CallLegInfoReport () {}

    /**
     * Creates a new CallLegInfoReport instance.
     * @param _callLegInfoType   The type of call leg information.
     * @param _callLegStartTime   The time and date when the call leg was started
(that is the leg was routed). 
     * @param _callLegConnectedToResourceTime   The date and time when the call leg was connected to the resource. If no resource was connected the time is set to an empty string.
Either this element is valid or the CallLegConnectedToAddressTime is valid, depending on whether the report is sent as a result of user interaction.
     * @param _callLegConnectedToAddressTime   The date and time when the call leg was connected to the destination (that is when the destination answered the call). If the destination did not answer, the time is set to an empty string.
Either this element is valid or the CallConnectedToResourceTime is valid, depending on whether the report is sent as a result of user interaction.
     * @param _callLegEndTime   The date and time when the call leg was released. 
     * @param _connectedAddress   The address of the party associated with the leg. If during the call the connected address was received from the party then this is returned, otherwise the destination address (for legs connected to a destination) or the originating address (for legs connected to the origination) is returned. 
     * @param _callLegReleaseCause   The cause of the termination. May be present with P_CALL_LEG_INFO_RELEASE_CAUSE was specified.
     * @param _callAppInfo   Additional information for the leg. May be present with P_CALL_LEG_INFO_APPINFO was specified.
     */
    public CallLegInfoReport (int _callLegInfoType, String _callLegStartTime, String _callLegConnectedToResourceTime, String _callLegConnectedToAddressTime, String _callLegEndTime, org.csapi.jr.se.Address _connectedAddress, org.csapi.jr.se.cc.ReleaseCause _callLegReleaseCause, org.csapi.jr.se.cc.CallAppInfo[] _callAppInfo) {

        this.callLegInfoType = _callLegInfoType;
        this.callLegStartTime = _callLegStartTime;
        this.callLegConnectedToResourceTime = _callLegConnectedToResourceTime;
        this.callLegConnectedToAddressTime = _callLegConnectedToAddressTime;
        this.callLegEndTime = _callLegEndTime;
        this.connectedAddress = _connectedAddress;
        this.callLegReleaseCause = _callLegReleaseCause;
        this.callAppInfo = _callAppInfo;
    }

    /**
     * This method returns a callLegInfoType.
     * 
     * @return a int value
     */
    public int getCallLegInfoType() {
        return callLegInfoType;
    }

    /**
     * This method returns a callLegStartTime.
     * 
     * @return a String value
     */
    public String getCallLegStartTime() {
        return callLegStartTime;
    }

    /**
     * This method returns a callLegConnectedToResourceTime.
     * 
     * @return a String value
     */
    public String getCallLegConnectedToResourceTime() {
        return callLegConnectedToResourceTime;
    }

    /**
     * This method returns a callLegConnectedToAddressTime.
     * 
     * @return a String value
     */
    public String getCallLegConnectedToAddressTime() {
        return callLegConnectedToAddressTime;
    }

    /**
     * This method returns a callLegEndTime.
     * 
     * @return a String value
     */
    public String getCallLegEndTime() {
        return callLegEndTime;
    }

    /**
     * This method returns a connectedAddress.
     * 
     * @return a org.csapi.jr.se.Address value
     */
    public org.csapi.jr.se.Address getConnectedAddress() {
        return connectedAddress;
    }

    /**
     * This method returns a callLegReleaseCause.
     * 
     * @return a org.csapi.jr.se.cc.ReleaseCause value
     */
    public org.csapi.jr.se.cc.ReleaseCause getCallLegReleaseCause() {
        return callLegReleaseCause;
    }

    /**
     * This method returns a callAppInfo.
     * 
     * @return a org.csapi.jr.se.cc.CallAppInfo[] value
     */
    public org.csapi.jr.se.cc.CallAppInfo[] getCallAppInfo() {
        return callAppInfo;
    }


    /**
     * This method sets a callLegInfoType.
     */ 
    public void setCallLegInfoType(int callLegInfoType) {
        this.callLegInfoType = callLegInfoType;
    }

    /**
     * This method sets a callLegStartTime.
     */ 
    public void setCallLegStartTime(String callLegStartTime) {
        this.callLegStartTime = callLegStartTime;
    }

    /**
     * This method sets a callLegConnectedToResourceTime.
     */ 
    public void setCallLegConnectedToResourceTime(String callLegConnectedToResourceTime) {
        this.callLegConnectedToResourceTime = callLegConnectedToResourceTime;
    }

    /**
     * This method sets a callLegConnectedToAddressTime.
     */ 
    public void setCallLegConnectedToAddressTime(String callLegConnectedToAddressTime) {
        this.callLegConnectedToAddressTime = callLegConnectedToAddressTime;
    }

    /**
     * This method sets a callLegEndTime.
     */ 
    public void setCallLegEndTime(String callLegEndTime) {
        this.callLegEndTime = callLegEndTime;
    }

    /**
     * This method sets a connectedAddress.
     */ 
    public void setConnectedAddress(org.csapi.jr.se.Address connectedAddress) {
        this.connectedAddress = connectedAddress;
    }

    /**
     * This method sets a callLegReleaseCause.
     */ 
    public void setCallLegReleaseCause(org.csapi.jr.se.cc.ReleaseCause callLegReleaseCause) {
        this.callLegReleaseCause = callLegReleaseCause;
    }

    /**
     * This method sets a callAppInfo.
     */ 
    public void setCallAppInfo(org.csapi.jr.se.cc.CallAppInfo[] callAppInfo) {
        this.callAppInfo = callAppInfo;
    }


    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }
        if(!(o instanceof CallLegInfoReport)) {
            return false;
        } 
        CallLegInfoReport callLegInfoReport = (CallLegInfoReport) o;
        if(!(this.callLegInfoType == callLegInfoReport.callLegInfoType))  {
            return false;
        }
        if(!(this.callLegStartTime == callLegInfoReport.callLegStartTime))  {
            return false;
        }
        if(!(this.callLegConnectedToResourceTime == callLegInfoReport.callLegConnectedToResourceTime))  {
            return false;
        }
        if(!(this.callLegConnectedToAddressTime == callLegInfoReport.callLegConnectedToAddressTime))  {
            return false;
        }
        if(!(this.callLegEndTime == callLegInfoReport.callLegEndTime))  {
            return false;
        }
        if ((this.connectedAddress != null) && (callLegInfoReport.connectedAddress != null)) {
            if(!(this.connectedAddress.equals(callLegInfoReport.connectedAddress))) {
                return false;
            }
        }
        if ((this.callLegReleaseCause != null) && (callLegInfoReport.callLegReleaseCause != null)) {
            if(!(this.callLegReleaseCause.equals(callLegInfoReport.callLegReleaseCause))) {
                return false;
            }
        }
        if(!(this.callAppInfo == callLegInfoReport.callAppInfo))  {
            return false;
        }
        if (this.hashCode() != o.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // CallLegInfoReport

