//Source file: CallLeg.java
//Date: June 2004
//Multi Party Call Control Interfaces for 3GPP TS 29.198-04-3 V5.7.0

package org.csapi.jr.se.cc.mpccs;

/**
 * This interface represents a CallLeg.<BR>
 *
 */
public interface CallLeg extends org.csapi.jr.se.Service {

    /**
     * Adds a CallLegListener which is interested in events generated by the CallLeg.
     *
     * @param  callLegListener  A reference to the CallLegListener which is to be added as
     *         a listener.
     */
    void addCallLegListener(org.csapi.jr.se.cc.mpccs.CallLegListener callLegListener);

    /**
     * Removes a CallLegListener which is no longer interested in events generated by the CallLeg.
     *
     * @param  callLegListener  A reference to the CallLegListener which is to be removed as
     *         a listener.
     */
    void removeCallLegListener(org.csapi.jr.se.cc.mpccs.CallLegListener callLegListener);

    /**
     * Returns a reference to the MultiPartyCall responsible for creation of the CallLeg.
     *
     * @return  A reference to the MultiPartyCall responsible for creation of the CallLeg.
     */
    org.csapi.jr.se.cc.mpccs.MultiPartyCall getMultiPartyCall();

    /**
     * Invokes the routeReq() method on the Parlay Gateway.
     */
    void routeReq(
           org.csapi.jr.se.Address targetAddress,
           org.csapi.jr.se.Address originatingAddress,
           org.csapi.jr.se.cc.CallAppInfo[] appInfo,
           org.csapi.jr.se.cc.CallLegConnectionProperties connectionProperties)
      throws org.csapi.jr.se.PlatformException,
       org.csapi.jr.se.CommonException,
       org.csapi.jr.se.InvalidNetworkStateException,
       org.csapi.jr.se.InvalidAddressException,
       org.csapi.jr.se.UnsupportedAddressPlanException;

    /**
     * Invokes the eventReportReq() method on the Parlay Gateway.
     */
    void eventReportReq(
           org.csapi.jr.se.cc.CallEventRequest[] eventsRequested)
      throws org.csapi.jr.se.PlatformException,
       org.csapi.jr.se.CommonException,
       org.csapi.jr.se.InvalidEventTypeException,
       org.csapi.jr.se.InvalidCriteriaException;

    /**
     * Invokes the release() method on the Parlay Gateway.
     */
    void release(
           org.csapi.jr.se.cc.ReleaseCause cause)
      throws org.csapi.jr.se.PlatformException,
       org.csapi.jr.se.CommonException,
       org.csapi.jr.se.InvalidNetworkStateException;

    /**
     * Invokes the getInfoReq() method on the Parlay Gateway.
     */
    void getInfoReq(
           int                             callLegInfoRequested)
      throws org.csapi.jr.se.PlatformException,
       org.csapi.jr.se.CommonException;

    /**
     * Invokes the attachMediaReq() method on the Parlay Gateway.
     */
    void attachMediaReq()
      throws org.csapi.jr.se.PlatformException,
       org.csapi.jr.se.CommonException,
       org.csapi.jr.se.InvalidNetworkStateException;

    /**
     * Invokes the detachMediaReq() method on the Parlay Gateway.
     */
    void detachMediaReq()
      throws org.csapi.jr.se.PlatformException,
       org.csapi.jr.se.CommonException,
       org.csapi.jr.se.InvalidNetworkStateException;

    /**
     * Invokes the getCurrentDestinationAddress() method on the Parlay Gateway.
     */
    org.csapi.jr.se.Address getCurrentDestinationAddress()
      throws org.csapi.jr.se.PlatformException,
       org.csapi.jr.se.CommonException;

    /**
     * Invokes the continueProcessing() method on the Parlay Gateway.
     */
    void continueProcessing()
      throws org.csapi.jr.se.PlatformException,
       org.csapi.jr.se.CommonException,
       org.csapi.jr.se.InvalidNetworkStateException;

    /**
     * Invokes the setChargePlan() method on the Parlay Gateway.
     */
    void setChargePlan(
           org.csapi.jr.se.cc.CallChargePlan callChargePlan)
      throws org.csapi.jr.se.PlatformException,
       org.csapi.jr.se.CommonException;

    /**
     * Invokes the setAdviceOfCharge() method on the Parlay Gateway.
     */
    void setAdviceOfCharge(
           org.csapi.jr.se.AoCInfo aOCInfo,
           int                             tariffSwitch)
      throws org.csapi.jr.se.PlatformException,
       org.csapi.jr.se.CommonException,
       org.csapi.jr.se.InvalidCurrencyException,
       org.csapi.jr.se.InvalidAmountException;

    /**
     * Invokes the superviseReq() method on the Parlay Gateway.
     */
    void superviseReq(
           int                             time,
           int                             treatment)
      throws org.csapi.jr.se.PlatformException,
       org.csapi.jr.se.CommonException;

    /**
     * Invokes the deassign() method on the Parlay Gateway.
     */
    void deassign()
      throws org.csapi.jr.se.PlatformException,
       org.csapi.jr.se.CommonException;

    /**
     * Invokes the getCall() method on the Parlay Gateway and returns a reference to a transient interface.
     */
    org.csapi.jr.se.cc.mpccs.MultiPartyCall getCall()
      throws org.csapi.jr.se.PlatformException,
       org.csapi.jr.se.CommonException;

}
