//Source file: MultiPartyCallControlManager.java
//Date: June 2004
//Multi Party Call Control Interfaces for 3GPP TS 29.198-04-3 V5.7.0

package org.csapi.jr.se.cc.mpccs;

/**
 * This interface represents a MultiPartyCallControlManager.<BR>
 *
 */
public interface MultiPartyCallControlManager extends org.csapi.jr.se.Service {

    /**
     * Adds a MultiPartyCallControlManagerListener which is interested in events generated by the MultiPartyCallControlManager.
     *
     * @param  multiPartyCallControlManagerListener  A reference to the MultiPartyCallControlManagerListener which is to be added as
     *         a listener.
     */
    void addMultiPartyCallControlManagerListener(org.csapi.jr.se.cc.mpccs.MultiPartyCallControlManagerListener multiPartyCallControlManagerListener);

    /**
     * Removes a MultiPartyCallControlManagerListener which is no longer interested in events generated by the MultiPartyCallControlManager.
     *
     * @param  multiPartyCallControlManagerListener  A reference to the MultiPartyCallControlManagerListener which is to be removed as
     *         a listener.
     */
    void removeMultiPartyCallControlManagerListener(org.csapi.jr.se.cc.mpccs.MultiPartyCallControlManagerListener multiPartyCallControlManagerListener);

    /**
     * Invokes the getNotification() method on the Parlay Gateway.
     *
     * @deprecated  This method is deprecated and will be removed in a later release.
     * It is strongly recommended not to implement this method. It has been replaced by getNextNotification().
     */
    org.csapi.jr.se.cc.NotificationRequested[] getNotification()
      throws org.csapi.jr.se.PlatformException,
       org.csapi.jr.se.CommonException;

    /**
     * Invokes the disableNotifications() method on the Parlay Gateway.
     */
    void disableNotifications()
      throws org.csapi.jr.se.PlatformException,
       org.csapi.jr.se.CommonException;

    /**
     * Invokes the getNextNotification() method on the Parlay Gateway.
     */
    org.csapi.jr.se.cc.NotificationRequestedSetEntry getNextNotification(
           boolean                         reset)
      throws org.csapi.jr.se.PlatformException,
       org.csapi.jr.se.CommonException;

    /**
     * Invokes the createCall() method on the Parlay Gateway and returns a reference to a transient interface.
     */
    org.csapi.jr.se.cc.mpccs.MultiPartyCall createCall()
      throws org.csapi.jr.se.PlatformException,
       org.csapi.jr.se.CommonException,
       org.csapi.jr.se.InvalidInterfaceTypeException;

    /**
     * Creates a CallLoadControl object and returns a reference to the interface used to gain access
     * to it's methods.
     *
     * @return  A reference to the CallLoadControl interface.
     */
    org.csapi.jr.se.cc.mpccs.CallLoadControl createCallLoadControl();

    /**
     * Creates a Notifications object and returns a reference to the interface used to gain access
     * to it's methods.
     *
     * @return  A reference to the Notifications interface.
     */
    org.csapi.jr.se.cc.mpccs.Notifications createNotifications();

    /**
     * Creates a Notification object and returns a reference to the interface used to gain access
     * to it's methods.
     *
     * @return  A reference to the Notification interface.
     */
    org.csapi.jr.se.cc.mpccs.Notification createNotification();

}
