//Source file: Notification.java
//Date: June 2004
//Multi Party Call Control Interfaces for 3GPP TS 29.198-04-3 V5.7.0

package org.csapi.jr.se.cc.mpccs;

/**
 * This interface represents a Notification activity object.<BR>
 *
 */
public interface Notification extends org.csapi.jr.se.Activity {

    /**
     * Returns a reference to the MultiPartyCallControlManager responsible for creation of the Notification.
     *
     * @return  A reference to the MultiPartyCallControlManager responsible for creation of the Notification.
     */
    org.csapi.jr.se.cc.mpccs.MultiPartyCallControlManager getMultiPartyCallControlManager();

    /**
     * Adds a NotificationListener which is interested in events generated by the Notification.
     *
     * @param  notificationListener  A reference to the NotificationListener which is to be added as
     *        a listener.
     */
    void addNotificationListener(org.csapi.jr.se.cc.mpccs.NotificationListener notificationListener);

    /**
     * Removes a NotificationListener which is no longer interested events generated by the Notification.
     *
     * @param  notificationListener  A reference to the NotificationListener which is to be removed as
     *        a listener.
     */
    void removeNotificationListener(org.csapi.jr.se.cc.mpccs.NotificationListener notificationListener);

    /**
     * Invokes the createNotification() method on the Parlay Gateway.
     */
    void createNotification(
           org.csapi.jr.se.cc.CallNotificationRequest notificationRequest)
      throws org.csapi.jr.se.PlatformException,
       java.lang.IllegalStateException,
       org.csapi.jr.se.CommonException,
       org.csapi.jr.se.InvalidCriteriaException,
       org.csapi.jr.se.InvalidInterfaceTypeException,
       org.csapi.jr.se.InvalidEventTypeException;

    /**
     * Invokes the destroyNotification() method on the Parlay Gateway.
     */
    void destroyNotification()
      throws org.csapi.jr.se.PlatformException,
       java.lang.IllegalStateException,
       org.csapi.jr.se.CommonException;

    /**
     * Invokes the changeNotification() method on the Parlay Gateway.
     */
    void changeNotification(
           org.csapi.jr.se.cc.CallNotificationRequest notificationRequest)
      throws org.csapi.jr.se.PlatformException,
       java.lang.IllegalStateException,
       org.csapi.jr.se.CommonException,
       org.csapi.jr.se.InvalidCriteriaException,
       org.csapi.jr.se.InvalidEventTypeException;
}
